#ifndef GEN_UI_GFX_X_BIGREQ_H_
#define GEN_UI_GFX_X_BIGREQ_H_

#include <array>
#include <cstddef>
#include <cstdint>
#include <cstring>
#include <vector>

#include "base/component_export.h"
#include "base/memory/ref_counted_memory.h"
#include "base/memory/scoped_refptr.h"
#include "base/optional.h"
#include "base/files/scoped_file.h"
#include "ui/gfx/x/xproto_types.h"
#include "xproto.h"

namespace x11 {

class Connection;

class COMPONENT_EXPORT(X11) BigRequests {
  public:
  static constexpr unsigned major_version = 0;
  static constexpr unsigned minor_version = 0;

  BigRequests(Connection* connection,
      const x11::QueryExtensionReply& info);

  uint8_t present() const {
    return info_.present;
  }
  uint8_t major_opcode() const {
    return info_.major_opcode;
  }
  uint8_t first_event() const {
    return info_.first_event;
  }
  uint8_t first_error() const {
    return info_.first_error;
  }

  Connection* connection() const { return connection_; }

  struct EnableRequest {
  };

  struct EnableReply {
    uint16_t sequence{};
    uint32_t maximum_request_length{};
  };

  using EnableResponse = Response<EnableReply>;

  Future<EnableReply> Enable(
      const EnableRequest& request);

  private:
  x11::Connection* const connection_;
  x11::QueryExtensionReply info_{};
};

}  // namespace x11


#endif  // GEN_UI_GFX_X_BIGREQ_H_
